{% ckan_extends %}

{% block header_account_logged %}
    {% if g.userobj.sysadmin %}
        <li>
            <a href="{{ h.url_for('logs.dashboard') }}" title="{{ _('Logs Dashboard') }}">
                <i class="fa fa-terminal" aria-hidden="true"></i>
            </a>
        </li>
    {% endif %}

    {{ super() }}
{% endblock %}
